@@ -1,16 +1,17 @@
 def replace_quotation_marks(language_code):
     quotation_marks_options = [
-        ("„", "“"),  # Option 1
-        ("«", "»"),  # Option 2
-        ("‘", "’"),  # Option 3
-        ("「", "」")  # Option 4
+        ("„", "“"),       # Option 1
+        ("«", "»"),       # Option 2
+        ("« ", " »"),     # Option 3
+        ("‘", "’"),       # Option 4
+        ("「", "」")      # Option 5
     ]
 
     print("Choose the kind of quotation marks by entering the corresponding number:")
     for i, marks in enumerate(quotation_marks_options, start=1):
         print(f"{i}. {marks[0]}…{marks[1]}")
     
-    choice = int(input("Your choice (1-4): ")) - 1
+    choice = int(input("Your choice (1-5): ")) - 1
     if choice < 0 or choice >= len(quotation_marks_options):
         print("Invalid choice. Exiting.")
         return
@@ -27,14 +28,16 @@ def replace_quotation_marks(language_code):
 
         updated_lines = []
         inside_msgstr_block = False
+        quote_open = False  # To keep track if we are inside a quote block
+
         for line in lines:
             if line.startswith('msgstr'):
                 inside_msgstr_block = True
                 if not line.strip() == 'msgstr ""':
-                    line, replacements = process_line(line, new_quotes)
+                    line, replacements, quote_open = process_line(line, new_quotes, quote_open)
                     replacement_count += replacements
             elif inside_msgstr_block and line.startswith('"'):
-                line, replacements = process_line(line, new_quotes)
+                line, replacements, quote_open = process_line(line, new_quotes, quote_open)
                 replacement_count += replacements
             else:
                 inside_msgstr_block = False
@@ -52,19 +55,22 @@ def replace_quotation_marks(language_code):
     except Exception as e:
         print(f"An error occurred: {e}")
 
-def process_line(line, new_quotes):
+def process_line(line, new_quotes, quote_open):
     replacements = 0
+
     # Continue replacing all occurrences of \" in the line
     while '\\"' in line:
-        # First replace with opening quote
-        line = line.replace('\\"', new_quotes[0], 1)
-        replacements += 1  # Increment since we found at least one pair
-        if '\\"' in line:  # Check if there's another \" for closing quote
+        if not quote_open:  # If quote is not open, replace opening quote
+            line = line.replace('\\"', new_quotes[0], 1)
+            quote_open = True
+        else:  # If quote is open, replace closing quote
             line = line.replace('\\"', new_quotes[1], 1)
-    return line, replacements
+            quote_open = False
+            replacements += 1
+
+    return line, replacements, quote_open
 
 # Example usage
 if __name__ == '__main__':
     language_code = input("Enter the language code (like zh_CN): ")
     replace_quotation_marks(language_code)
-
